@@ -30,7 +30,10 @@ umount "$HOME" || umount -l "$HOME" || true
 rm -rf "$HOME"
 
 # remove leftovers in /tmp
-find /tmp -mindepth 1 -maxdepth 1 -uid "$UID" | xargs rm -rf
+find /tmp -mindepth 1 -maxdepth 1 -uid "$UID" | xargs rm -rf || true
+
+# remove gdm cache files
+find /var/cache/gdm -mindepth 1 -maxdepth 1 -uid "$UID" | xargs rm -rf || true
 
 deluser --system "$USER"
 
